@@ -1,5 +1,5 @@
 """Exceptions for the evergreen module."""
-from typing import Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional
 
 if TYPE_CHECKING:
     from evergreen.task import Task
