@@ -18,6 +18,7 @@ if TYPE_CHECKING:
 EVG_SUCCESS_STATUS = "success"
 EVG_SYSTEM_FAILURE_STATUS = "system"
 EVG_UNDISPATCHED_STATUS = "undispatched"
+EVG_TEST_STATUS_TYPE = "test"
 
 _EVG_DATE_FIELDS_IN_TASK = frozenset(
     ["create_time", "dispatch_time", "finish_time", "ingest_time", "scheduled_time", "start_time"]
@@ -161,6 +162,16 @@ class Task(_BaseEvergreenObject):
             self._logs_map = {key: value for key, value in self.json["logs"].items()}
         return self._logs_map
 
+    def get_project_identifier(self) -> str:
+        """
+        Retrieve the human-readable project id from Evergreen.
+
+        This requires the caller to be Admin on the project.
+
+        :return: Human-readable project id.
+        """
+        return self._api.project_by_id(self.project_id).identifier
+
     def retrieve_log(self, log_name: str, raw: bool = False) -> str:
         """
         Retrieve the contents of the specified log.
@@ -258,6 +269,16 @@ class Task(_BaseEvergreenObject):
         """
         return self.status == EVG_SUCCESS_STATUS
 
+    def is_test_failure(self) -> bool:
+        """
+        Whether task was a test failure.
+
+        :return: True is task was a test failure.
+        """
+        if not self.is_success() and self.status_details and self.status_details.type:
+            return self.status_details.type == EVG_TEST_STATUS_TYPE
+        return False
+
     def is_undispatched(self) -> bool:
         """
         Whether the task was undispatched.
